==> webcamoid_8.0.0+dfsg.orig.tar.gz: webcamoid-8.0.0/libAvKys/Plugins/Aging/src/agingelement.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef AGINGELEMENT_H
#define AGINGELEMENT_H

#include <QMutex>
#include <QQmlComponent>
#include <QQmlContext>
#include <ak.h>
#include <akutils.h>

#include "scratch.h"

class AgingElement: public AkElement
{
    Q_OBJECT
    Q_PROPERTY(int nScratches
               READ nScratches
               WRITE setNScratches
               RESET resetNScratches
               NOTIFY nScratchesChanged)
    Q_PROPERTY(bool addDust
               READ addDust
               WRITE setAddDust
               RESET resetAddDust
               NOTIFY addDustChanged)

    public:
        explicit AgingElement();

        Q_INVOKABLE QObject *controlInterface(QQmlEngine *engine,
                                              const QString &controlId) const;

        Q_INVOKABLE int nScratches() const;
        Q_INVOKABLE bool addDust() const;

    private:
        QVector<Scratch> m_scratches;
        bool m_addDust;

        QMutex m_mutex;

        QImage colorAging(const QImage &src);
        void scratching(QImage &dest);
        void pits(QImage &dest);
        void dusts(QImage &dest);

    signals:
        void nScratchesChanged(int nScratches);
        void addDustChanged(bool addDust);

    public slots:
        void setNScratches(int nScratches);
        void setAddDust(bool addDust);
        void resetNScratches();
        void resetAddDust();

        AkPacket iStream(const AkPacket &packet);
};

#endif // AGINGELEMENT_H

==> webcamoid_8.1.0+dfsg.orig.tar.gz: webcamoid-8.1.0+dfsg/libAvKys/Plugins/Aging/src/agingelement.h <==
/* Webcamoid, webcam capture application.
 * Copyright (C) 2011-2017  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#ifndef AGINGELEMENT_H
#define AGINGELEMENT_H

#include <QMutex>
#include <ak.h>
#include <akutils.h>

#include "scratch.h"

class AgingElement: public AkElement
{
    Q_OBJECT
    Q_PROPERTY(int nScratches
               READ nScratches
               WRITE setNScratches
               RESET resetNScratches
               NOTIFY nScratchesChanged)
    Q_PROPERTY(bool addDust
               READ addDust
               WRITE setAddDust
               RESET resetAddDust
               NOTIFY addDustChanged)

    public:
        explicit AgingElement();

        Q_INVOKABLE int nScratches() const;
        Q_INVOKABLE bool addDust() const;

    private:
        QVector<Scratch> m_scratches;
        bool m_addDust;

        QMutex m_mutex;

        QImage colorAging(const QImage &src);
        void scratching(QImage &dest);
        void pits(QImage &dest);
        void dusts(QImage &dest);

    protected:
        QString controlInterfaceProvide(const QString &controlId) const;
        void controlInterfaceConfigure(QQmlContext *context,
                                       const QString &controlId) const;

    signals:
        void nScratchesChanged(int nScratches);
        void addDustChanged(bool addDust);

    public slots:
        void setNScratches(int nScratches);
        void setAddDust(bool addDust);
        void resetNScratches();
        void resetAddDust();

        AkPacket iStream(const AkPacket &packet);
};

#endif // AGINGELEMENT_H
